@@ -44,6 +44,7 @@
 
 #define MONOSPACE_FONT_DIR "/desktop/gnome/interface"
 #define MONOSPACE_FONT_KEY MONOSPACE_FONT_DIR "/monospace_font_name"
+#define HTTP_PROXY_DIR "/system/http_proxy"
 
 struct _TerminalScreenPrivate
 {
@@ -52,7 +53,6 @@ struct _TerminalScreenPrivate
   TerminalProfile *profile; /* may be NULL at times */
   guint profile_changed_id;
   guint profile_forgotten_id;
-  int id;
   GtkWidget *popup_menu;
   char *raw_title, *raw_icon_title;
   char *cooked_title, *cooked_icon_title;
@@ -69,11 +69,9 @@ struct _TerminalScreenPrivate
   guint gconf_connection_id;
   GtkWidget *hbox;
   GtkWidget *scrollbar;
-  char **environ;
+  gboolean user_title; /* title was manually set */
 };
 
-static GList* used_ids = NULL;
-
 enum {
   PROFILE_SET,
   TITLE_CHANGED,
@@ -83,12 +81,10 @@ enum {
   LAST_SIGNAL
 };
 
-enum
-{
-  FLAVOR_AS_IS = 0,
+enum {
+  FLAVOR_AS_IS,
   FLAVOR_DEFAULT_TO_HTTP,
-  FLAVOR_MAILTO,
-  FLAVOR_SKEY
+  FLAVOR_EMAIL
 };
 
 static void terminal_screen_init        (TerminalScreen      *screen);
@@ -123,8 +119,6 @@ static void terminal_screen_widget_encoding_changed  (GtkWidget      *term,
 
 static void terminal_screen_setup_dnd                (TerminalScreen *screen);
 
-static void reread_profile (TerminalScreen *screen);
-
 static gboolean cook_title  (TerminalScreen *screen, const char *raw_title, char **old_cooked_title);
 
 static void terminal_screen_cook_title      (TerminalScreen *screen);
@@ -266,10 +260,9 @@ terminal_screen_init (TerminalScreen *screen)
   if (screen->priv->working_dir == NULL) /* shouldn't ever happen */
     screen->priv->working_dir = g_strdup (g_get_home_dir ());
   screen->priv->child_pid = -1;
-  screen->priv->environ = NULL;
 
   screen->priv->recheck_working_dir_idle = 0;
-  
+
   screen->priv->term = terminal_widget_new ();
 
   screen->priv->font_scale = PANGO_SCALE_MEDIUM;
@@ -278,29 +271,34 @@ terminal_screen_init (TerminalScreen *screen)
 #define PASSCHARS "-A-Za-z0-9,?;.:/!%$^*&~\"#'"
 #define HOSTCHARS "-A-Za-z0-9"
 #define PATHCHARS "-A-Za-z0-9_$.+!*(),;:@&=?/~#%"
-#define SCHEME    "(news|telnet|nntp|file|https?|ftps?|webcal)"
+#define SCHEME    "(news:|telnet:|nntp:|file:/|https?:|ftps?:|webcal:)"
 #define USER      "[" USERCHARS "]+(:["PASSCHARS "]+)?"
 #define URLPATH   "/[" PATHCHARS "]*[^]'.}>) \t\r\n,\\\"]"
 
   terminal_widget_match_add (screen->priv->term,
-      "\\<(" SCHEME "://(" USER "@)?)[" HOSTCHARS ".]+(:[0-9]+)?(" URLPATH ")?", FLAVOR_AS_IS);
+			     "\\<" SCHEME "//(" USER "@)?[" HOSTCHARS ".]+"
+			     "(:[0-9]+)?(" URLPATH ")?\\>/?", FLAVOR_AS_IS);
 
   terminal_widget_match_add (screen->priv->term,
-      "\\<(www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+(:[0-9]+)?(" URLPATH ")?", FLAVOR_DEFAULT_TO_HTTP);
+			     "\\<(www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+"
+			     "(:[0-9]+)?(" URLPATH ")?\\>/?",
+			     FLAVOR_DEFAULT_TO_HTTP);
 
-  terminal_widget_match_add (screen->priv->term,       
-      "\\<(mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9][a-z0-9-]*(\\.[a-z0-9][a-z0-9-]*)+\\>", FLAVOR_MAILTO);
-	  
   terminal_widget_match_add (screen->priv->term,
-      "\\<news:[-A-Z\\^_a-z{|}~!\"#$%&'()*+,./0-9;:=?`]+@[" HOSTCHARS ".]+(:[0-9]+)?\\>", FLAVOR_AS_IS);
+			     "\\<(mailto:)?[a-z0-9][a-z0-9.-]*@[a-z0-9]"
+			     "[a-z0-9-]*(\\.[a-z0-9][a-z0-9-]*)+\\>",
+			     FLAVOR_EMAIL);
 
+  terminal_widget_match_add (screen->priv->term,
+			     "\\<news:[-A-Z\\^_a-z{|}~!\"#$%&'()*+,./0-9;:=?`]+"
+			     "@[" HOSTCHARS ".]+(:[0-9]+)?\\>", FLAVOR_AS_IS);
 
   terminal_screen_setup_dnd (screen);
-  
+
   g_object_set_data (G_OBJECT (screen->priv->term),
                      "terminal-screen",
                      screen);
-  
+
   g_signal_connect (G_OBJECT (screen->priv->term),
                     "realize",
                     G_CALLBACK (terminal_screen_update_on_realize),
@@ -310,7 +308,7 @@ terminal_screen_init (TerminalScreen *screen)
                     "style_set",
                     G_CALLBACK (style_set_callback),
                     screen);
-  
+
   g_signal_connect (G_OBJECT (screen->priv->term),
                     "popup_menu",
                     G_CALLBACK (terminal_screen_popup_menu),
@@ -321,6 +319,7 @@ terminal_screen_init (TerminalScreen *screen)
                     G_CALLBACK (terminal_screen_button_press_event),
                     screen);
 
+  screen->priv->user_title = FALSE;
   terminal_widget_connect_title_changed (screen->priv->term,
                                          G_CALLBACK (terminal_screen_widget_title_changed),
                                          screen);
@@ -435,8 +434,6 @@ terminal_screen_finalize (GObject *object)
 
   g_object_unref (conf);
 
-  used_ids = g_list_remove (used_ids, GINT_TO_POINTER (screen->priv->id));  
-
   if (screen->priv->title_editor)
     gtk_widget_destroy (screen->priv->title_editor);
   
@@ -452,37 +449,16 @@ terminal_screen_finalize (GObject *object)
   g_free (screen->priv->matched_string);
   g_strfreev (screen->priv->override_command);
   g_free (screen->priv->working_dir);
-  g_strfreev (screen->priv->environ);
   
   g_free (screen->priv);
   
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static int
-next_unused_id (void)
-{
-  /* can't this be changed into a static unsigned long int? These ids are never used anyways...*/
-  int i = 0;
-
-  while (g_list_find (used_ids, GINT_TO_POINTER (i)))
-    ++i;
-
-  return i;
-}
-
 TerminalScreen*
 terminal_screen_new (void)
 {
-  TerminalScreen *screen;
-
-  screen = g_object_new (TERMINAL_TYPE_SCREEN, NULL);
-  
-  screen->priv->id = next_unused_id ();
-
-  used_ids = g_list_prepend (used_ids, GINT_TO_POINTER (screen->priv->id));
-  
-  return screen;
+  return g_object_new (TERMINAL_TYPE_SCREEN, NULL);
 }
 
 static void
@@ -498,12 +474,6 @@ terminal_screen_map (GtkWidget *widget)
   GTK_WIDGET_CLASS (parent_class)->map (widget);
 }
 
-int
-terminal_screen_get_id (TerminalScreen *screen)
-{
-  return screen->priv->id;
-}
-
 TerminalWindow*
 terminal_screen_get_window (TerminalScreen *screen)
 {
@@ -549,12 +519,13 @@ terminal_screen_get_icon_title_set (TerminalScreen *screen)
   return screen->priv->icon_title_set;
 }
 
-static void
-reread_profile (TerminalScreen *screen)
+void
+terminal_screen_reread_profile (TerminalScreen *screen)
 {
   TerminalProfile *profile;
   GtkWidget *term;
   TerminalBackgroundType bg_type;
+  TerminalWindow *window;
   
   profile = screen->priv->profile;  
   
@@ -600,7 +571,12 @@ reread_profile (TerminalScreen *screen)
   if (terminal_profile_get_use_skey (screen->priv->profile))
     {
       terminal_widget_skey_match_add (screen->priv->term,
-				      "s/key [0-9]* [-A-Za-z0-9]*", FLAVOR_SKEY);
+				      "s/key [0-9]* [-A-Za-z0-9]*",
+				      FLAVOR_AS_IS);
+
+      terminal_widget_skey_match_add (screen->priv->term,
+				      "otp-[a-z0-9]* [0-9]* [-A-Za-z0-9]*",
+				      FLAVOR_AS_IS);
     }
   else
     {
@@ -623,13 +599,24 @@ reread_profile (TerminalScreen *screen)
 
   if (bg_type == TERMINAL_BACKGROUND_IMAGE ||
       bg_type == TERMINAL_BACKGROUND_TRANSPARENT)
+    {
     terminal_widget_set_background_darkness (term,
                                              terminal_profile_get_background_darkness (profile));
+      terminal_widget_set_background_opacity (term,
+					      terminal_profile_get_background_darkness (profile));
+    }      
   else
+    {
     terminal_widget_set_background_darkness (term, 0.0); /* normal color */
+      terminal_widget_set_background_opacity (term, 1);
+    }
   
+  window = terminal_screen_get_window (screen);
+  if (window == NULL || !terminal_window_uses_argb_visual (window))
   terminal_widget_set_background_transparent (term,
                                               bg_type == TERMINAL_BACKGROUND_TRANSPARENT);
+  else
+    terminal_widget_set_background_transparent (term, FALSE);
 
   terminal_widget_set_backspace_binding (term,
                                          terminal_profile_get_backspace_binding (profile));
@@ -686,7 +673,6 @@ cook_title  (TerminalScreen *screen, const char *raw_title, char **old_cooked_ti
       break;
     case TERMINAL_TITLE_IGNORE:
       new_cooked_title = g_strdup (terminal_profile_get_title (screen->priv->profile));
-      break;
     /* no default so we get missing cases statically */
     }
 
@@ -722,7 +708,7 @@ profile_changed_callback (TerminalProfile           *profile,
                           const TerminalSettingMask *mask,
                           TerminalScreen            *screen)
 {
-  reread_profile (screen);
+  terminal_screen_reread_profile (screen);
 }
 
 static void
@@ -815,7 +801,8 @@ terminal_screen_update_on_realize (GtkWidget      *term,
                                        screen->priv->font_scale *
                                        pango_font_description_get_size (desc));
 
-      terminal_widget_set_pango_font (term, desc);
+      terminal_widget_set_pango_font (term, desc,
+				      terminal_profile_get_no_aa_without_render (profile));
 
       pango_font_description_free (desc);
     }
@@ -969,7 +956,7 @@ terminal_screen_set_profile (TerminalScreen *screen,
 
   screen->priv->profile = profile;
 
-  reread_profile (screen);
+  terminal_screen_reread_profile (screen);
 
   if (screen->priv->profile)
     g_signal_emit (G_OBJECT (screen), signals[PROFILE_SET], 0);
@@ -1098,29 +1085,19 @@ static char**
 get_child_environment (GtkWidget      *term,
                        TerminalScreen *screen)
 {
-  /* code from gnome-terminal, sort of. */
-  TerminalProfile *profile;
-  char **p;
-  int i;
-  char **retval;
-  char **env;
-#define EXTRA_ENV_VARS 7
-  
-  profile = screen->priv->profile;
-  /* if screen->priv->environ is defined, we should use that instead */
-  if (screen->priv->environ)
-	  env = screen->priv->environ;
-  else
-	  env = environ;
+  gchar **p, **retval;
+  gint i;
+  GConfClient *conf;
+#define EXTRA_ENV_VARS 8
 
   /* count env vars that are set */
-  for (p = env; *p; p++)
+  for (p = environ; *p; p++)
     ;
-  
-  i = p - env;
+
+  i = p - environ;
   retval = g_new (char *, i + 1 + EXTRA_ENV_VARS);
 
-  for (i = 0, p = env; *p; p++)
+  for (i = 0, p = environ; *p; p++)
     {
       /* Strip all these out, we'll replace some of them */
       if ((strncmp (*p, "COLUMNS=", 8) == 0) ||
@@ -1129,7 +1106,7 @@ get_child_environment (GtkWidget      *term,
           (strncmp (*p, "TERM=", 5) == 0)    ||
           (strncmp (*p, "GNOME_DESKTOP_ICON=", 19) == 0) ||
           (strncmp (*p, "COLORTERM=", 10) == 0) ||
-	  (strncmp ( *p, "DISPLAY=", 8) == 0))
+	  (strncmp (*p, "DISPLAY=", 8) == 0))
         {
           /* nothing: do not copy */
         }
@@ -1142,17 +1119,116 @@ get_child_environment (GtkWidget      *term,
 
   retval[i] = g_strdup ("COLORTERM="EXECUTABLE_NAME);
   ++i;
+
   retval[i] = g_strdup ("TERM=xterm"); /* FIXME configurable later? */
   ++i;
+
   retval[i] = g_strdup_printf ("WINDOWID=%ld",
                                GDK_WINDOW_XWINDOW (term->window));
   ++i;
+
   retval[i] = g_strdup_printf ("DISPLAY=%s", 
 			       gdk_display_get_name(gtk_widget_get_display(term)));
   ++i;
   
+  conf = gconf_client_get_default ();
+
+  if (!getenv ("http_proxy") &&
+      gconf_client_get_bool (conf, HTTP_PROXY_DIR "/use_http_proxy", NULL))
+    {
+      gint port;
+      GSList *ignore;
+      gchar *host, *auth = NULL;
+
+      host = gconf_client_get_string (conf, HTTP_PROXY_DIR "/host", NULL);
+      port = gconf_client_get_int (conf, HTTP_PROXY_DIR "/port", NULL);
+      ignore = gconf_client_get_list (conf, HTTP_PROXY_DIR "/ignore_hosts",
+				      GCONF_VALUE_STRING, NULL);
+
+      if (gconf_client_get_bool (conf, HTTP_PROXY_DIR "/use_authentication", NULL))
+	{
+	  gchar *user, *password;
+
+	  user = gconf_client_get_string (conf,
+					  HTTP_PROXY_DIR "/authentication_user",
+					  NULL);
+
+	  password = gconf_client_get_string (conf,
+					      HTTP_PROXY_DIR
+					      "/authentication_password",
+					      NULL);
+
+	  if (user != '\0')
+	    auth = g_strdup_printf ("%s:%s", user, password);
+
+	  g_free (user);
+	  g_free (password);
+	}
+
+      g_object_unref (conf);
+
+      if (port && host && host != '\0')
+	{
+	  if (auth)
+	    retval[i] = g_strdup_printf ("http_proxy=http://%s@%s:%d/",
+					 auth, host, port);
+	  else
+	    retval[i] = g_strdup_printf ("http_proxy=http://%s:%d/",
+					 host, port);
+
+	  ++i;
+	}
+
+      if (auth)
+	g_free (auth);
+
+      if (host)
+	g_free (host);
+
+      if (ignore)
+	{
+	  /* code distantly based on gconf's */
+	  gchar *buf = NULL;
+	  guint bufsize = 64;
+	  guint cur = 0;
+
+	  buf = g_malloc (bufsize + 3);
+
+	  while (ignore != NULL)
+	    {
+	      guint len = strlen (ignore->data);
+
+	      if ((cur + len + 2) >= bufsize) /* +2 for '\0' and comma */
+		{
+		  bufsize = MAX(bufsize * 2, bufsize + len + 4); 
+		  buf = g_realloc (buf, bufsize + 3);
+		}
+
+	      g_assert (cur < bufsize);
+
+	      strcpy (&buf[cur], ignore->data);
+	      cur += len;
+
+	      g_assert(cur < bufsize);
+
+	      buf[cur] = ',';
+	      ++cur;
+
+	      g_assert(cur < bufsize);
+
+	      ignore = g_slist_next (ignore);
+	    }
+
+	  buf[cur-1] = '\0'; /* overwrites last comma */
+
+	  retval[i] = g_strdup_printf ("no_proxy=%s", buf);
+	  g_free (buf);
+	  ++i;
+	}
+    }
+
   retval[i] = NULL;
-  
+
   return retval;
 }
 
@@ -1233,7 +1309,7 @@ new_window_callback (GtkWidget      *menu_item,
                              NULL,
                              FALSE, FALSE, FALSE,
                              NULL, NULL, NULL, dir, NULL, 1.0,
-                             NULL, name, -1, NULL);
+                             NULL, name, -1);
 
   g_free (name);
 }
@@ -1252,7 +1328,7 @@ new_tab_callback (GtkWidget      *menu_item,
                              NULL,
                              FALSE, FALSE, FALSE,
                              NULL, NULL, NULL, dir, NULL, 1.0,
-                             NULL, NULL, -1, NULL);
+                             NULL, NULL, -1);
 }
 
 static void
@@ -1337,18 +1413,13 @@ open_url (TerminalScreen *screen,
     case FLAVOR_DEFAULT_TO_HTTP:
       url = g_strdup_printf ("http:%s", orig_url);
       break;
-    case FLAVOR_MAILTO:
-      if (strncmp ("mailto:", orig_url, 7) != 0)
-        {
-          url = g_strdup_printf ("mailto:%s", orig_url);
-        }
+    case FLAVOR_EMAIL:
+      if (strncmp ("mailto:", orig_url, 7))
+	url = g_strdup_printf ("mailto:%s", orig_url);
       else
-        {
-          url = g_strdup (orig_url);
-        }
+	url = g_strdup (orig_url);
       break;
     case FLAVOR_AS_IS:
-    case FLAVOR_SKEY:
       url = g_strdup (orig_url);
       break;
     default:
@@ -1425,9 +1496,9 @@ popup_menu_detach (GtkWidget *attach_widget,
 
 static GtkWidget*
 append_menuitem (GtkWidget  *menu,
-                 const char *text,
-                 GCallback   callback,
-                 gpointer    data)
+		 const char *text,
+		 GCallback   callback,
+		 gpointer    data)
 {
   GtkWidget *menu_item;
   
@@ -1534,45 +1605,57 @@ popup_clipboard_request_callback (GtkClipboard *clipboard,
   screen = info->screen;
 
   if (!GTK_WIDGET_REALIZED (screen->priv->term)) 
-    {
-      goto cleanup;
-    }
+    goto cleanup;
 
   if (screen->priv->popup_menu)
-    {
-      gtk_widget_destroy (screen->priv->popup_menu);
-    }
+    gtk_widget_destroy (screen->priv->popup_menu);
 
   screen->priv->popup_menu = gtk_menu_new ();
   gtk_menu_set_accel_group (GTK_MENU (screen->priv->popup_menu),
                             terminal_accels_get_group_for_widget (screen->priv->popup_menu));
-  
+
   gtk_menu_attach_to_widget (GTK_MENU (screen->priv->popup_menu),
                              GTK_WIDGET (screen->priv->term),
                              popup_menu_detach);
 
   if (screen->priv->matched_string != NULL) 
     {
-      menu_item = append_menuitem (screen->priv->popup_menu,
-                                   _("_Open Link"),
-                                   G_CALLBACK (open_url_callback),
-                                   screen);
-      
-      menu_item = append_menuitem (screen->priv->popup_menu,
-                                   _("_Copy Link Address"),
-                                   G_CALLBACK (copy_url_callback),
-                                   screen);
-  
+      if (screen->priv->matched_flavor == FLAVOR_EMAIL &&
+	  strncmp ("mailto:", screen->priv->matched_string, 7))
+	{
+	  menu_item = append_menuitem (screen->priv->popup_menu,
+				       _("_Send Mail To..."),
+				       G_CALLBACK (open_url_callback),
+				       screen);
+
+	  menu_item = append_menuitem (screen->priv->popup_menu,
+				       _("_Copy E-mail Address"),
+				       G_CALLBACK (copy_url_callback),
+				       screen);
+	}
+      else
+	{
+	  menu_item = append_menuitem (screen->priv->popup_menu,
+				       _("_Open Link"),
+				       G_CALLBACK (open_url_callback),
+				       screen);
+
+	  menu_item = append_menuitem (screen->priv->popup_menu,
+				       _("_Copy Link Address"),
+				       G_CALLBACK (copy_url_callback),
+				       screen);
+	}
       menu_item = gtk_separator_menu_item_new ();
       gtk_widget_show (menu_item);
-      gtk_menu_shell_append (GTK_MENU_SHELL (screen->priv->popup_menu), menu_item);
+      gtk_menu_shell_append (GTK_MENU_SHELL (screen->priv->popup_menu),
+			     menu_item);
     }
- 
+
   menu_item = append_menuitem (screen->priv->popup_menu,
                                _("Open _Terminal"),
                                G_CALLBACK (new_window_callback),
                                screen);
-  
+
   menu_item = append_menuitem (screen->priv->popup_menu,
                                _("Open Ta_b"),
                                G_CALLBACK (new_tab_callback),
@@ -1777,12 +1860,14 @@ terminal_screen_button_press_event (GtkWidget      *widget,
 
 void
 terminal_screen_set_dynamic_title (TerminalScreen *screen,
-                                   const char     *title)
+                                   const char     *title,
+				   gboolean	  userset)
 {
-  g_return_if_fail (TERMINAL_IS_SCREEN (screen));
+  g_assert (TERMINAL_IS_SCREEN (screen));
   
-  if (screen->priv->raw_title && title &&
-      strcmp (screen->priv->raw_title, title) == 0)
+  if ((screen->priv->user_title && !userset) ||
+      (screen->priv->raw_title && title &&
+       strcmp (screen->priv->raw_title, title) == 0))
     return;
 
   g_free (screen->priv->raw_title);
@@ -1807,12 +1892,16 @@ terminal_screen_set_dynamic_title (TerminalScreen *screen,
 
 void
 terminal_screen_set_dynamic_icon_title (TerminalScreen *screen,
-                                        const char     *icon_title)
+                                        const char     *icon_title,
+					gboolean       userset)
 {
-  g_return_if_fail (TERMINAL_IS_SCREEN (screen));
-  
-  if (screen->priv->icon_title_set && screen->priv->raw_icon_title && icon_title &&
-      strcmp (screen->priv->raw_icon_title, icon_title) == 0)
+  g_assert (TERMINAL_IS_SCREEN (screen));
+
+  if ((screen->priv->user_title && !userset) ||  
+      (screen->priv->icon_title_set &&
+       screen->priv->raw_icon_title &&
+       icon_title &&
+       strcmp (screen->priv->raw_icon_title, icon_title) == 0))
     return;
 
   g_free (screen->priv->raw_icon_title);
@@ -1847,16 +1936,6 @@ terminal_screen_set_working_dir (TerminalScreen *screen,
   screen->priv->working_dir = g_strdup (dirname);
 }
 
-void
-terminal_screen_set_environ (TerminalScreen *screen,
-                             char          **env)
-{
-  g_return_if_fail (TERMINAL_IS_SCREEN (screen));
-
-  g_free (screen->priv->environ);
-  screen->priv->environ = g_strdupv (env);
-}
-
 const char*
 terminal_screen_get_working_dir (TerminalScreen *screen)
 {
@@ -1972,7 +2051,8 @@ terminal_screen_widget_title_changed (GtkWidget      *widget,
                                       TerminalScreen *screen)
 {
   terminal_screen_set_dynamic_title (screen,
-                                     terminal_widget_get_title (widget));  
+                                     terminal_widget_get_title (widget),
+				     FALSE);
 
   queue_recheck_working_dir (screen);
 }
@@ -1982,7 +2062,8 @@ terminal_screen_widget_icon_title_changed (GtkWidget      *widget,
                                            TerminalScreen *screen)
 {
   terminal_screen_set_dynamic_icon_title (screen,
-                                          terminal_widget_get_icon_title (widget));  
+                                          terminal_widget_get_icon_title (widget),
+					  FALSE);  
 
   queue_recheck_working_dir (screen);
 }
@@ -2034,8 +2115,17 @@ title_entry_changed (GtkWidget      *entry,
   char *text;
 
   text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-  
-  terminal_screen_set_dynamic_title (screen, text);
+
+  /* The user set the title to nothing, let's understand that as a
+     request to revert to dynamically setting the title again. */
+  if (G_UNLIKELY (*text == '\0'))
+    screen->priv->user_title = FALSE;
+  else
+    {
+      screen->priv->user_title = TRUE;
+      terminal_screen_set_dynamic_title (screen, text, TRUE);
+      terminal_screen_set_dynamic_icon_title (screen, text, TRUE);
+    }
 
   g_free (text);
 }
